@@ -162,7 +162,9 @@ class GitLibMixin:
                     item, pygit2.Object
                 ), "item is not a pygit2.Object"
                 self.__index.add(
-                    pygit2.IndexEntry(toItemPath.as_posix(), item.oid, item.filemode)
+                    pygit2.IndexEntry(
+                        toItemPath.as_posix(), item.oid, item.filemode
+                    )
                 )
                 self.__index.remove(fromItemPath.as_posix())
 
@@ -180,7 +182,9 @@ class GitLibMixin:
         blob = fromTree / fromPath.name
         assert isinstance(blob, pygit2.Object), "blob is not a pygit2.Object"
 
-        self.__index.add(pygit2.IndexEntry(toPath.as_posix(), blob.oid, blob.filemode))
+        self.__index.add(
+            pygit2.IndexEntry(toPath.as_posix(), blob.oid, blob.filemode)
+        )
         self.__index.remove(fromPath.as_posix())
         self.__isIndexDirty = True
 
@@ -526,7 +530,7 @@ class GitLibMixin:
                 raise MergeConflict("Cannot complete merge due to conflicts")
 
             self.__createCommit(
-                makeRef(self.__checkedOutBranch),
+                checked.name,
                 "Merge",
                 [checkedBranchId, sourceBranchId],
             )
