@@ -1,14 +1,28 @@
 from collections import namedtuple
 from pathlib import Path
 
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_7Z,
+)
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_TAR,
+)
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_TAR_BZ2,
+)
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_TAR_GZ,
+)
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_TAR_XZ,
+)
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_UNKNOWN,
+)
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_ZIP,
+)
 
-ARCHIVE_FORMAT_KEY_ZIP = "zip"
-ARCHIVE_FORMAT_KEY_7Z = "7z"
-ARCHIVE_FORMAT_KEY_TAR = "tar"
-ARCHIVE_FORMAT_KEY_TAR_GZ = "tar.gz"
-ARCHIVE_FORMAT_KEY_TAR_BZ2 = "tar.bz2"
-ARCHIVE_FORMAT_KEY_TAR_XZ = "tar.xz"
-ARCHIVE_FORMAT_KEY_UNKNOWN = "unknown"
 
 ArchiveFormat = namedtuple("ArchiveFormat", ["key", "name", "extensions"])
 archiveFormatByKey = {
